@@ -112,6 +112,12 @@ class WebOption(Config):
             text_list = [i.text for i in ele]
             return text_list
 
+    @_retrying
+    def GetElement(self,selector: str):
+        """定位单个元素"""
+        ele = self.locate_element(selector)
+        return ele
+
     @_retrying
     def GetElements(self, selector: str, text: str = "",index: int = None,):
         """获取一组元素"""
@@ -252,3 +258,11 @@ class WebOption(Config):
             key = cookie.split("=")[0]
             value = cookie.split("=")[1]
             self.baseDriver.add_cookie({"name": key, "value": value})
+
+    def GetCookie(self,name):
+        """获取指定key的cookie"""
+        return self.baseDriver.get_cookie(name)
+
+    def GetCookies(self):
+        """获取当前会话的所有cookie"""
+        return self.baseDriver.get_cookies()
