@@ -1,9 +1,8 @@
 # -*- coding = UTF-8 -*-
-# Author   :buxiubuzhi
-# File     : utils.py
-# project  : Python_project
-# time     : 2020/11/16 17:01
-# Describe : 工具类
+# Author   : buxiubuzhi
+# Project  : lazyTest
+# FileName : utils.py
+# Describe :
 # ---------------------------------------
 
 import datetime
@@ -92,3 +91,16 @@ def ClearTestResult(path: str):
             os.remove(path_file)
         else:
             ClearTestResult(path_file)
+
+def clearLogAndReport(ProjectPath):
+    def clear(func):
+        nonlocal ProjectPath
+        @functools.wraps(func)
+        def inner(*args,**kwargs):
+            print("----------清空上次测试结果----------")
+            path = ProjectPath + "/result"
+            ClearTestResult(path)
+            result = func(*args,**kwargs)
+            return result
+        return inner
+    return clear
